@@ -25,6 +25,7 @@ import urllib.parse
 
 from gi.repository import Gdk, GdkPixbuf, GObject, Gtk, GtkSource, Pango
 
+from rednotebook.gui.options import OptionsManager
 from rednotebook import info, templates
 from rednotebook.gui import (
     browser,
@@ -39,7 +40,6 @@ from rednotebook.gui import (
 from rednotebook.gui.customwidgets import CustomComboBoxEntry, CustomListView
 from rednotebook.gui.exports import ExportAssistant
 from rednotebook.gui.menu import MainMenuBar
-from rednotebook.gui.options import OptionsManager
 from rednotebook.util import dates, filesystem, markup, urls, utils
 
 
@@ -173,6 +173,9 @@ class MainWindow:
                     pass
 
             self.html_editor = Preview(self.journal)
+            self.html_editor.connect(
+                "on-url-clicked", lambda _, url: self.navigate_to_uri(url)
+            )
             self.text_vbox.pack_start(self.html_editor, True, True, 0)
         else:
             self.html_editor = mock.MagicMock()
@@ -324,13 +327,13 @@ class MainWindow:
             [
                 (
                     "Show",
-                    Gtk.STOCK_MEDIA_PLAY,
+                    None,
                     _("Show RedNotebook"),
                     None,
                     None,
                     lambda widget: self.show(),
                 ),
-                ("Quit", Gtk.STOCK_QUIT, None, None, None, self.on_quit_activate),
+                ("Quit", None, None, None, None, self.on_quit_activate),
             ]
         )
 
@@ -550,18 +553,19 @@ class MainWindow:
             action = decision.get_navigation_action()
             if action.is_user_gesture():
                 uri = action.get_request().get_uri()
-                logging.info('Clicked URI "%s"' % uri)
-
-                if urls.is_entry_reference_uri(uri):
-                    self.navigate_to_referenced_entry(uri)
-                else:
-                    urls.open_url(uri)
-
+                self.navigate_to_uri(uri)
                 decision.ignore()
 
         # Stop processing this event.
         return True
 
+    def navigate_to_uri(self, uri):
+        logging.info('Navigating to URI "%s"' % uri)
+        if urls.is_entry_reference_uri(uri):
+            self.navigate_to_referenced_entry(uri)
+        else:
+            urls.open_url(uri)
+
     def navigate_to_referenced_entry(self, entry_reference_uri):
         entry_reference_uri = urllib.parse.urlparse(entry_reference_uri)
         date = dates.get_date_from_date_string(entry_reference_uri.fragment)
@@ -674,7 +678,7 @@ class MainWindow:
             self.template_button.set_menu(self.template_manager.get_menu())
 
         self.template_button = customwidgets.ToolbarMenuButton(
-            Gtk.STOCK_PASTE, self.template_manager.get_menu()
+            "edit-paste", self.template_manager.get_menu()
         )
         self.template_button.set_label(_("Template"))
         self.template_button.connect("clicked", update_menu)
